===============================
certbot-dns-transip
===============================

Certbot plugin to authenticate using dns TXT records via Transip API


* Documentation: https://readthedocs.org/projects/certbot-dns-transip/

Features
--------

* TODO
